@@ -1,4 +1,21 @@
-## this file contains short methods definitions
+## this file contains some basic methods definitions
+
+## functions to extract or call the components of a "pomp" object
+data.array <- function (object, ...)
+  stop("function ",sQuote("data.array")," is undefined for objects of class ",sQuote(class(object)))
+setGeneric('data.array')  
+
+"time<-" <- function (object, ..., value)
+  stop("function ",sQuote("time<-")," is undefined for objects of class ",sQuote(class(object)))
+setGeneric("time<-")  
+
+"coef<-" <- function (object, pars, ..., value)
+  stop("function ",sQuote("coef<-")," is undefined for objects of class ",sQuote(class(object)))
+setGeneric("coef<-")
+
+states <- function (object, ...)
+  stop("function ",sQuote("states")," is undefined for objects of class ",sQuote(class(object)))
+setGeneric('states')
 
 ## 'coerce' method: allows for coercion of a "pomp" object to a data-frame
 setAs(
